import java.util.*;

import visual.dynamic.described.*;
import visual.statik.sampled.*;

/**
 * A Pinecone in the game Flakey
 *
 * A Pinecone is a simple rule-based sprite that uses one piece
 * of visual content.  Unlike a Snowflake, a Pinecone is not
 * always falling.
 *
 * @author  Prof. David Bernstein, James Madison University
 * @version 1.0
 */
public class Pinecone extends RuleBasedSprite
{
    private boolean            moving;
    private int                x, xStart, y, yStart, speed;

    private static Random      rng = new Random();

    
    /**
     * Explicit Value Constructor
     */
    public Pinecone(TransformableContent content)
    {
        super(content);
    }
    
    
    /**
     * Handle a tick event (generated by the Stage)
     *
     * @param time  The current time (in milliseconds)
     */
    public void handleTick(int time)
    {
        int           wait;
        
        if (!moving)
        {
            wait = rng.nextInt(1000);
            if (wait >= 990) moving = true;
        }
        
        if (moving && visible)
        {
            y += speed;
            
            if (y > 640)
            {
                visible= false;
            }
            setLocation(x, y);            
        }
    }
    
    
    /**
     * Set the starting values
     *
     * @param xStart   The intial x-coordinate
     * @param yStart   The intial y-coordinate
     * @param speed    The intial speed
     */
    public void setStartingValues(int xStart, int yStart, int speed)
    {
        this.moving = false;
        this.xStart = xStart;
        this.yStart = yStart;
        this.x      = xStart;
        this.y      = yStart;
        this.speed  = speed;
        setLocation(x, y);        
   }
}
